@@ -7,15 +7,30 @@ use ExtUtils::MakeMaker ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.57';
+	$VERSION = '0.58';
 	@ISA     = qw{Module::Install::Base};
 }
 
 sub Makefile { $_[0] }
 
+my %seen = ();
+
 sub prompt {
     shift;
-    goto &ExtUtils::MakeMaker::prompt;
+
+    # Infinite loop protection
+    my @c = caller();
+    if ( ++$seen{"$c[1]|$c[2]|$_[0]"} > 3 ) {
+        die "Caught an potential prompt infinite loop ($c[1]|$c[2]|$_[0])";
+    }
+
+    # In automated testing, always use defaults
+    if ( $ENV{AUTOMATED_TESTING} and ! $ENV{PERL_MM_USE_DEFAULT} ) {
+        local $ENV{PERL_MM_USE_DEFAULT} = 1;
+        goto &ExtUtils::MakeMaker::prompt;
+    } else {
+        goto &ExtUtils::MakeMaker::prompt;
+    }
 }
 
 sub makemaker_args {
@@ -69,25 +84,26 @@ sub write {
     die "&Makefile->write() takes no arguments\n" if @_;
 
     my $args = $self->makemaker_args;
-
     $args->{DISTNAME} = $self->name;
-    $args->{NAME} = $self->module_name || $self->name || $self->determine_NAME($args);
-    $args->{VERSION} = $self->version || $self->determine_VERSION($args);
-    $args->{NAME} =~ s/-/::/g;
-
-    $args->{test} = {TESTS => $self->tests} if $self->tests;
-
+    $args->{NAME}     = $self->module_name || $self->name || $self->determine_NAME($args);
+    $args->{VERSION}  = $self->version || $self->determine_VERSION($args);
+    $args->{NAME}     =~ s/-/::/g;
+    if ( $self->tests ) {
+        $args->{test} = { TESTS => $self->tests };
+    }
     if ($] >= 5.005) {
         $args->{ABSTRACT} = $self->abstract;
-        $args->{AUTHOR} = $self->author;
+        $args->{AUTHOR}   = $self->author;
     }
     if ( eval($ExtUtils::MakeMaker::VERSION) >= 6.10 ) {
         $args->{NO_META} = 1;
     }
-    if ( eval($ExtUtils::MakeMaker::VERSION) > 6.17 ) {
-        $args->{SIGN} = 1 if $self->sign;
+    if ( eval($ExtUtils::MakeMaker::VERSION) > 6.17 and $self->sign ) {
+        $args->{SIGN} = 1;
+    }
+    unless ( $self->is_admin ) {
+        delete $args->{SIGN};
     }
-    delete $args->{SIGN} unless $self->is_admin;
 
     # merge both kinds of requires into prereq_pm
     my $prereq = ($args->{PREREQ_PM} ||= {});
@@ -104,49 +120,48 @@ sub write {
         }
     }
 
-    if (my $perl_version = $self->perl_version) {
+    if ( my $perl_version = $self->perl_version ) {
         eval "use $perl_version; 1"
-            or die "ERROR: perl: Version $] is installed, ".
-                   "but we need version >= $perl_version";
+            or die "ERROR: perl: Version $] is installed, "
+                . "but we need version >= $perl_version";
     }
 
-    my %args = map {($_ => $args->{$_})} grep {defined($args->{$_})} keys %$args;
-
+    my %args = map { ( $_ => $args->{$_} ) } grep {defined($args->{$_})} keys %$args;
     if ($self->admin->preop) {
         $args{dist} = $self->admin->preop;
     }
 
-    ExtUtils::MakeMaker::WriteMakefile(%args);
-
-    $self->fix_up_makefile();
+    my $mm = ExtUtils::MakeMaker::WriteMakefile(%args);
+    $self->fix_up_makefile($mm->{FIRST_MAKEFILE});
 }
 
 sub fix_up_makefile {
-    my $self = shift;
-    my $top_class = ref($self->_top) || '';
-    my $top_version = $self->_top->VERSION || '';
+    my $self          = shift;
+    my $makefile_name = shift;
+    my $top_class     = ref($self->_top) || '';
+    my $top_version   = $self->_top->VERSION || '';
 
     my $preamble = $self->preamble 
-       ? "# Preamble by $top_class $top_version\n" . $self->preamble
-       : '';
-    my $postamble = "# Postamble by $top_class $top_version\n" . 
-                    ($self->postamble || '');
+        ? "# Preamble by $top_class $top_version\n"
+            . $self->preamble
+        : '';
+    my $postamble = "# Postamble by $top_class $top_version\n"
+        . ($self->postamble || '');
 
     local *MAKEFILE;
-    open MAKEFILE, '< Makefile' or die $!;
+    open MAKEFILE, "< $makefile_name" or die "fix_up_makefile: Couldn't open $makefile_name: $!";
     my $makefile = do { local $/; <MAKEFILE> };
     close MAKEFILE or die $!;
 
     $makefile =~ s/\b(test_harness\(\$\(TEST_VERBOSE\), )/$1'inc', /;
     $makefile =~ s/( -I\$\(INST_ARCHLIB\))/ -Iinc$1/g;
     $makefile =~ s/( "-I\$\(INST_LIB\)")/ "-Iinc"$1/g;
+    $makefile =~ s/^(FULLPERL = .*)/$1 "-Iinc"/m;
+    $makefile =~ s/^(PERL = .*)/$1 "-Iinc"/m;
 
-    $makefile =~ s/^(FULLPERL = .*)/$1 -Iinc/m;
-    $makefile =~ s/^(PERL = .*)/$1 -Iinc/m;
-
-    open MAKEFILE, '> Makefile' or die $!;
-    print MAKEFILE "$preamble$makefile$postamble" or die $!;
-    close MAKEFILE or die $!;
+    open  MAKEFILE, "> $makefile_name" or die "fix_up_makefile: Couldn't open $makefile_name: $!";
+    print MAKEFILE  "$preamble$makefile$postamble" or die $!;
+    close MAKEFILE  or die $!;
 
     1;
 }
@@ -168,4 +183,4 @@ sub postamble {
 
 __END__
 
-#line 295
+#line 312
